<?php

namespace Drupal\tg_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\tg_integration\TgIntegrationSettings;

/**
 * Defines a form that configures forms module settings.
 */
class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tg_integration_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'tg_integration.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('tg_integration.settings');
    $form['api_settings'] = [
      '#type' => 'details',
      '#title' => t('Telegram API settings'),
      '#open' => TRUE,
    ];
    $form['api_settings']['token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bot authentication token'),
      '#default_value' => $config->get('token'),
      '#placeholder' => '123456:ABC-DEF1234ghIkl-zyx57W2v1u123ew11'
    ];
    $form['api_settings']['chat_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Chat name'),
      '#default_value' => $config->get('chat_name'),
      '#placeholder' => 'chat_name'
    ];
    $form['api_settings']['post_to_tg'] = [
      '#type' => 'checkbox',
      '#title' => t('Post node to the Telegram chanel'),
      '#default_value' => $config->get('post_to_tg'),
      '#description' => t('Default option for the nodes.'),
    ];
    $form['api_settings']['display_comments'] = [
      '#type' => 'checkbox',
      '#title' => t('Display comments block'),
      '#default_value' => $config->get('display_comments'),
      '#description' => t('Display Telegram comments block for the new nodes.'),
    ];
    $form['api_settings']['silent_mode'] = [
      '#type' => 'checkbox',
      '#title' => t('Silent mode'),
      '#default_value' => $config->get('silent_mode'),
      '#description' => t('Send post to the Telegram chanel in silent mode (without sound notification).'),
    ];
    /* @var \Drupal\tg_integration\TgIntegrationSettings $settings */
    $settings = \Drupal::service('tg_integration.settings');
    $entity_options = $settings->getEntitiesOptions();
    $form['content_settings'] = [
      '#type' => 'details',
      '#title' => t('Content integrations settings'),
      '#open' => TRUE,
    ];
    $form['content_settings']['content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content Types'),
      '#options' => $entity_options,
      '#empty_option' => $this->t('- Select an existing content type -'),
      '#default_value' => $config->get('content_types'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('tg_integration.settings')
      ->set('token', $values['token'])
      ->set('chat_name', $values['chat_name'])
      ->set('post_to_tg', $values['post_to_tg'])
      ->set('display_comments', $values['display_comments'])
      ->set('silent_mode', $values['silent_mode'])
      ->set('content_types', $values['content_types'])
      ->set('custom_bundles', $values['custom_bundles'])
      ->save();
    parent::submitForm($form, $form_state);
  }

}
