<?php

namespace Drupal\tg_integration;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Entity\ContentEntityType;

class TgIntegrationSettings {

   /**
   * The config factory object.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * The module config (settings).
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  private ImmutableConfig $settings;

  /**
   * Constructs a ServiceExample object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A configuration factory instance.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
    $this->settings = $this->configFactory->get('tg_integration.settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getContentEntities() {

    $entity_types = [];
    $skipped_entity_types = [
      'block_content',
      'media',
      'menu_link_content',
      'redirect',
      'shortcut',
      'user'
    ];
    $entity_type_definitions = \Drupal::entityTypeManager()->getDefinitions();

    foreach ($entity_type_definitions as $definition) {
      if ($definition instanceof ContentEntityType) {
        $entity_id = $definition->id();
        $entity_link = $definition->hasLinkTemplate('canonical');
        $entity_bundles = \Drupal::service('entity_type.bundle.info')->getBundleInfo($entity_id);
        if ($entity_link && $entity_bundles && !in_array($entity_id, $skipped_entity_types)) {
          $entity_types[$entity_id] = array_keys($entity_bundles);
        }
      }
    }

    return $entity_types;
  }

  /**
   * {@inheritdoc}
   */
  public function checkedEntityBundle($entity): bool {
    $content_types = $this->settings->get('content_types') ?? [];
    return in_array($entity->getEntityTypeId() . '|' . $entity->bundle(), array_filter($content_types));
  }

  /**
   * {@inheritdoc}
   */
  public function checkedEntityType($entity_type): bool {
    $content_types = $this->settings->get('content_types') ?? [];
    $checked_entities = [];
    foreach ($content_types as $content_type) {
      if ($content_type) {
        $checked_entities[] = strtok($content_type, '|');
      }
    }
    $checked_entities = array_unique($checked_entities);

    return in_array($entity_type->id(), $checked_entities);
  }

  /**
   * Returns a list of all the content types currently installed.
   *
   * @return array
   *   An array of content types.
   */
  public function getEntitiesOptions() {
    $options = [];
    $entities =  self::getContentEntities();
    foreach ($entities as $entity => $bundles) {
      foreach ($bundles as $bundle) {
        $options[$entity . '|' . $bundle] = ucfirst($bundle) . ' (' . $entity . ')';
      }
    }

    return $options;
  }

}

